---
title: <span class="badge builder"></span> ElasticsearchUniqueCountSettings
---
# <span class="badge builder"></span> ElasticsearchUniqueCountSettings

## Constructor

```python
ElasticsearchUniqueCountSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchUniqueCountSettings
```

### <span class="badge object-method"></span> missing

```python
def missing(missing: str) -> typing.Self
```

### <span class="badge object-method"></span> precision_threshold

```python
def precision_threshold(precision_threshold: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchUniqueCountSettings](./object-ElasticsearchUniqueCountSettings.md)
